Package: nara
Type: Package
Title: Native Raster Image Tools
Version: 1.0.2
Authors@R: c(
    person("Mike", "Cheng", role = c("aut", "cre", 'cph'), email = "mikefc@coolbutuseless.com"),
    person("Julien", "Vernay", role = "ctb", 
    comment = "Author of public domain code for thick polylines")
    )
Maintainer: Mike Cheng <mikefc@coolbutuseless.com>
Description: Native rasters are a core R image format which use a compact
    color representation. This color representation closely aligns with
    graphics device internals meaning that these images can be rendered quickly.
    This package provides functions to quickly create, manipulate and composite native
    rasters.
URL: https://github.com/coolbutuseless/nara,
        https://coolbutuseless.github.io/package/nara/index.html
BugReports: https://github.com/coolbutuseless/nara/issues
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
LinkingTo: colorfast
Depends: R (>= 4.1.0)
Imports: colorfast
Suggests: testthat (>= 3.0.0), jpeg, fastpng, png, knitr, rmarkdown,
        magick
Config/testthat/edition: 3
Copyright: The included 'deer' sprites are by Calciumtrice and licensed
        under CC BY 3.0.  See 'inst/LICENSE-deer.txt' for more details.
        The included bitmap font 'spleen' was created by Frederic
        Cambus (c) 2018-2024. See 'inst/LICENSE-spleen.txt' for full
        LICENSE
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-05-28 10:34:36 UTC; mike
Author: Mike Cheng [aut, cre, cph],
  Julien Vernay [ctb] (Author of public domain code for thick polylines)
Repository: CRAN
Date/Publication: 2026-05-28 13:50:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-05-28 16:35:19 UTC; unix
Archs: nara.so.dSYM
