# Generated by roxygen2: do not edit by hand

S3method(plot,nativeRaster)
S3method(print,nativeRaster)
export(array_to_nr)
export(is_nativeraster)
export(magick_to_nr)
export(matrix_to_nr)
export(nr_blit)
export(nr_blit_multi)
export(nr_circle)
export(nr_color_replace)
export(nr_copy)
export(nr_copy_into)
export(nr_crop)
export(nr_crop2)
export(nr_desaturate)
export(nr_dither)
export(nr_fill)
export(nr_fliph)
export(nr_flipv)
export(nr_line)
export(nr_mask_begin)
export(nr_mask_end)
export(nr_new)
export(nr_new_from)
export(nr_point)
export(nr_polygon)
export(nr_polyline)
export(nr_rect)
export(nr_resize)
export(nr_rotate)
export(nr_scale)
export(nr_text_mono)
export(nr_threshold)
export(nr_to_array)
export(nr_to_magick)
export(nr_to_raster)
export(nr_transpose)
export(nr_tri_coords)
export(nr_tri_mesh)
export(nrs_to_gif)
export(nrs_to_mp4)
export(raster_to_nr)
import(colorfast)
import(grid)
importFrom(grDevices,dev.flush)
importFrom(grDevices,dev.hold)
useDynLib(nara, .registration=TRUE)
