% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nr-core.R
\name{print.nativeRaster}
\alias{print.nativeRaster}
\title{Print method}
\usage{
\method{print}{nativeRaster}(x, ...)
}
\arguments{
\item{x}{native raster image}

\item{...}{ignored}
}
\value{
None
}
\description{
Print method
}
\examples{
nr <- nr_new(500, 400)
print(nr)
}
