% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-sets.R
\docType{data}
\name{deer}
\alias{deer}
\title{Deer images - a list of native raster images}
\format{
An object of class \code{list} of length 15.
}
\usage{
deer
}
\description{
The 'deer' sprites are by Calciumtrice and licensed under CC BY 3.0.  
See 'inst/LICENSE-deer.txt' for more details. To view license information:
}
\details{
\code{cat(readLines(system.file('LICENSE-deer.txt', package = 'nara')), sep = "\n")}
}
\keyword{datasets}
