% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nr-core.R
\name{nr_fill}
\alias{nr_fill}
\title{Fill a native raster image with the given color}
\usage{
nr_fill(nr, color)
}
\arguments{
\item{nr}{native raster image}

\item{color}{Color as a character string. Either a standard R color
(e.g. 'blue', 'white')
or a hex color of the form \code{#rrggbbaa}, \code{#rrggbb}, \code{#rgba}
or \code{#rgb}}
}
\value{
Invisibly return the supplied native raster image which was been
        modified in-place
}
\description{
Fill a native raster image with the given color
}
\examples{
nr <- nr_new(400, 300, 'hotpink')
nr_fill(nr, 'blue')
plot(nr)

}
